@@ -7,7 +7,7 @@ from django.utils.translation import gettext_lazy as _
 from bread import layout
 
 from ...layout.components.datatable import DataTableColumn
-from .fields.queryfield import QuerysetField
+from .fields.queryfield import QuerysetField, parsequeryexpression
 
 
 def available_report_filters(modelfield, request, report):
@@ -76,7 +76,7 @@ class Report(models.Model):
                     )
                     % (self.custom_queryset, self.model.model_class(), ret.model)
                 )
-            return ret
+            return parsequeryexpression(ret, self.filter.raw).queryset
         return self.filter.queryset
 
     def __str__(self):
